@@ -18,25 +18,24 @@ __copyright__ = """
 __license__ = "Apache 2.0"
 
 import csv
-import sys
 import json
-import yaml
-import requests
-import shapely
-import clipboard
-import visvalingamwyatt as vw
+import sys
 from datetime import date
-from shapely.geometry import shape
-from prettytable import PrettyTable
-from planet.api.utils import read_planet_json
-from planet.api.auth import find_api_key
 
+import clipboard
+import jwt
+import requests
+import visvalingamwyatt as vw
+import yaml
+from prettytable import PrettyTable
 
 x = PrettyTable()
 
 ovall = []
 
 # get coordinates list depth
+
+
 def list_depth(dic, level=1):
     counter = 0
     str_dic = str(dic)
@@ -49,7 +48,7 @@ def list_depth(dic, level=1):
     return counter
 
 
-##Setup for bundles
+# Setup for bundles
 dbundle = {
     "name": [],
     "subscription_id": [],
@@ -112,11 +111,28 @@ dszip = {
         "single_archive": True,
     }
 }
-try:
-    PL_API_KEY = find_api_key()
-except:
-    print("Failed to get Planet Key")
-    sys.exit()
+
+
+def authenticate_session():
+    try:
+        if not os.path.exists(os.path.join(expanduser("~"), "planet.auth.json")):
+            os.system("porder init")
+        else:
+            with open(os.path.join(expanduser("~"), "planet.auth.json")) as json_file:
+                token_data = json.load(json_file)
+                encoded = token_data["token"]
+                api_key = jwt.decode(encoded, options={"verify_signature": False})[
+                    'api_key']
+        PL_API_KEY = api_key
+    except Exception as error:
+        print(error)
+        print("Failed to get Planet Key")
+        sys.exit()
+    SESSION = requests.Session()
+    SESSION.auth = (PL_API_KEY, "")
+    return SESSION
+
+
 url = "https://api.planet.com/compute/ops/orders/v2"
 
 
@@ -162,6 +178,9 @@ def vertexcount(input):
 
 
 def order(**kwargs):
+    import shapely
+    from shapely.geometry import shape
+    SESSION = authenticate_session()
     for key, value in kwargs.items():
         if key == "name":
             dbundle["name"] = value
@@ -225,23 +244,29 @@ def order(**kwargs):
                 elif items == "projection":
                     dbundle["tools"].append(dreproject)
                 elif items == "ndvi":
-                    dndvi = {"pixel_type": "32R", "ndvi": "(b4 - b3) / (b4 + b3)"}
+                    dndvi = {"pixel_type": "32R",
+                             "ndvi": "(b4 - b3) / (b4 + b3)"}
                     dbmath["bandmath"].update(dndvi)
                 elif items == "gndvi":
-                    dgndvi = {"pixel_type": "32R", "gndvi": "(b4 - b2) / (b4 + b2)"}
+                    dgndvi = {"pixel_type": "32R",
+                              "gndvi": "(b4 - b2) / (b4 + b2)"}
                     dbmath["bandmath"].update(dgndvi)
                 elif items == "ndwi":
-                    dndwi = {"pixel_type": "32R", "ndwi": "(b2 - b4) / (b4 + b2)"}
+                    dndwi = {"pixel_type": "32R",
+                             "ndwi": "(b2 - b4) / (b4 + b2)"}
                     dbmath["bandmath"].update(dndwi)
                 elif items == "bndvi":
-                    bndvi = {"pixel_type": "32R", "bndvi": "(b4 - b1) / (b4 + b1)"}
+                    bndvi = {"pixel_type": "32R",
+                             "bndvi": "(b4 - b1) / (b4 + b1)"}
                     dbmath["bandmath"].update(bndvi)
                 elif items == "tvi_deering":
-                    dtvi_deering = {"pixel_type": "32R", "tvi_deering": "(((b4 - b3) / (b4 + b3)) + 0.5) ** 0.5"}
+                    dtvi_deering = {
+                        "pixel_type": "32R", "tvi_deering": "(((b4 - b3) / (b4 + b3)) + 0.5) ** 0.5"}
                     dbmath["bandmath"].update(dtvi_deering)
                 elif items == "tvi_brogeleblanc":
-                    dtvi_brogeleblanc = {"pixel_type": "32R", "tvi_brogeleblanc": "0.5 * ((120 * (b4 - b2) / 10000) - (200 * (b3 - b2) / 10000))"}
-                    dbmath["bandmath"].update(dtvi_brogeleblanc)                   
+                    dtvi_brogeleblanc = {
+                        "pixel_type": "32R", "tvi_brogeleblanc": "0.5 * ((120 * (b4 - b2) / 10000) - (200 * (b3 - b2) / 10000))"}
+                    dbmath["bandmath"].update(dtvi_brogeleblanc)
                 elif items == "osavi":
                     dosavi = {
                         "pixel_type": "32R",
@@ -275,10 +300,12 @@ def order(**kwargs):
                             aoi_resp = multipoly(value)
                             try:
                                 for things in aoi_resp["features"]:
-                                    ovall.append(things["geometry"]["coordinates"])
+                                    ovall.append(
+                                        things["geometry"]["coordinates"])
                             except Exception:
                                 for things in json.loads(aoi_resp)["features"]:
-                                    ovall.append(things["geometry"]["coordinates"])
+                                    ovall.append(
+                                        things["geometry"]["coordinates"])
 
                             aoi_geom = ovall
                             if (
@@ -370,9 +397,6 @@ def order(**kwargs):
                                 items["clip"]["aoi"]["coordinates"] = aoi_resp[
                                     "config"
                                 ][0]["config"]["coordinates"]
-                        elif value.endswith(".kml"):
-                            getcoord = kml2coord(value)
-                            items["clip"]["aoi"]["coordinates"] = getcoord
                     except Exception as e:
                         print(e)
                         # print('Could not parse geometry')
@@ -468,7 +492,8 @@ def order(**kwargs):
 
     rg = len(bnames)
     if rg < 6:
-        dck = ["b" + str(el) for el in range(1, rg + 1)]  # get serialized bands
+        dck = ["b" + str(el)
+               for el in range(1, rg + 1)]  # get serialized bands
         plist = [list(pair) for pair in zip(dck, bnames)]
         x.field_names = ["Band Number", "Band Name"]
         for items in plist:
@@ -492,7 +517,7 @@ def order(**kwargs):
     # print('')
     # print(dbmath)
 
-    #print(payload)
+    # print(payload)
     ordname = k["name"]
     payload = payload.replace(
         "{{name}}_{{order_id}}.zip",
@@ -500,9 +525,8 @@ def order(**kwargs):
     )
     # print(payload)
     headers = {"content-type": "application/json", "cache-control": "no-cache"}
-    response = requests.request(
-        "POST", url, data=payload, headers=headers, auth=(PL_API_KEY, "")
-    )
+    SESSION.headers.update(headers)
+    response = SESSION.post(url, data=payload)
     if response.status_code == 202:
         content = response.json()
         try:
