@@ -1,5 +1,15 @@
 from __future__ import print_function
 
+import visvalingamwyatt as vw
+
+from .async_downloader import asyncdownload
+from .downloader import download
+from .geojson2id import idl
+from .order_now import order
+from .ordstat import ostat
+from .resubmit import reorder
+from .text_split import idsplit
+
 __copyright__ = """
 
     Copyright 2021 Samapriya Roy
@@ -19,116 +29,28 @@ __copyright__ = """
 """
 __license__ = "Apache 2.0"
 
-import subprocess
 import argparse
-import os
-import time
-import sys
-import json
 import base64
-import requests
-import webbrowser
-import clipboard
+import getpass
+import json
+import os
 import platform
-import datetime
-import pkg_resources
-import dateutil.parser
-from bs4 import BeautifulSoup
-from pySmartDL import SmartDL
+import subprocess
+import sys
+import time
+import webbrowser
 from os.path import expanduser
 
-if str(platform.system().lower()) == "windows":
-    # Get python runtime version
-    version = sys.version_info[0]
-    try:
-        import pipwin
-
-        if pipwin.__version__ == "0.5.0":
-            pass
-        else:
-            a = subprocess.call(
-                "{} -m pip install pipwin==0.5.0".format(sys.executable),
-                shell=True,
-                stdout=subprocess.PIPE,
-            )
-            b = subprocess.call(
-                "{} -m pip install wheel".format(sys.executable),
-                shell=True,
-                stdout=subprocess.PIPE,
-            )
-            subprocess.call("pipwin refresh", shell=True)
-        """Check if the pipwin cache is old: useful if you are upgrading porder on windows
-        [This section looks if the pipwin cache is older than two weeks]
-        """
-        home_dir = expanduser("~")
-        fullpath = os.path.join(home_dir, ".pipwin")
-        file_mod_time = os.stat(fullpath).st_mtime
-        if int((time.time() - file_mod_time) / 60) > 90000:
-            print("Refreshing your pipwin cache")
-            subprocess.call("pipwin refresh", shell=True)
-    except ImportError:
-        a = subprocess.call(
-            "{} -m pip install pipwin==0.5.0".format(sys.executable),
-            shell=True,
-            stdout=subprocess.PIPE,
-        )
-        subprocess.call("pipwin refresh", shell=True)
-    except Exception as e:
-        print(e)
-    try:
-        import gdal
-    except ImportError:
-        from osgeo import gdal
-    except ImportError:
-        subprocess.call("pipwin install gdal", shell=True)
-    except Exception as e:
-        print(e)
-    try:
-        import pyproj
-    except ImportError:
-        subprocess.call("pipwin install pyproj", shell=True)
-    except Exception as e:
-        print(e)
-    try:
-        import shapely
-    except ImportError:
-        subprocess.call("pipwin install shapely", shell=True)
-    except Exception as e:
-        print(e)
-    try:
-        import fiona
-    except ImportError:
-        subprocess.call("pipwin install fiona", shell=True)
-    except Exception as e:
-        print(e)
-    try:
-        import geopandas
-    except ImportError:
-        subprocess.call("pipwin install geopandas", shell=True)
-    except Exception as e:
-        print(e)
-from .conv2geojson import convert
-from .geojson_simplify import geosimple
-from .geojson2id import idl
-from .text_split import idsplit
-from .order_now import order
-from .order_size import ordersize
-from .downloader import download
-from .diffcheck import checker
-from .ordstat import ostat
-from .async_downloader import asyncdownload
-from .idcheck import idc
-from .resubmit import reorder
-from planet.api.auth import find_api_key
-
-if str(platform.python_version()) > "3.3.0":
-    from .async_down import downloader
-os.chdir(os.path.dirname(os.path.realpath(__file__)))
-lpath = os.path.dirname(os.path.realpath(__file__))
-sys.path.append(lpath)
+import clipboard
+import dateutil.parser
+import jwt
+import pkg_resources
+import requests
+from bs4 import BeautifulSoup
+from logzero import logger
+from pySmartDL import SmartDL
 
 
-# Get package version
 class Solution:
     def compareVersion(self, version1, version2):
         versions1 = [int(v) for v in version1.split(".")]
@@ -145,15 +67,78 @@ class Solution:
 
 ob1 = Solution()
 
-# Get package version
+if str(platform.system().lower()) == "windows":
+    version = sys.version_info[0]
+    try:
+        import pipgeo
+        response = requests.get('https://pypi.org/pypi/pipgeo/json')
+        latest_version = response.json()['info']['version']
+        vcheck = ob1.compareVersion(
+            latest_version,
+            pkg_resources.get_distribution("pipgeo").version,
+        )
+        if vcheck == 1:
+            subprocess.call(
+                f"{sys.executable}" + " -m pip install pipgeo --upgrade", shell=True
+            )
+    except ImportError:
+        subprocess.call(
+            f"{sys.executable}" + " -m pip install pipgeo", shell=True
+        )
+    except Exception as e:
+        logger.exception(e)
+    try:
+        from osgeo import gdal
+    except ModuleNotFoundError or ImportError:
+        subprocess.call("pipgeo fetch --lib gdal", shell=True)
+    except Exception as e:
+        logger.exception(e)
+    try:
+        import pyproj
+    except ModuleNotFoundError or ImportError:
+        subprocess.call("pipgeo fetch --lib pyproj", shell=True)
+        import pyproj
+    except Exception as e:
+        logger.exception(e)
+    try:
+        import shapely
+    except ModuleNotFoundError or ImportError:
+        subprocess.call("pipgeo fetch --lib shapely", shell=True)
+    except Exception as e:
+        logger.exception(e)
+    try:
+        import fiona
+    except ModuleNotFoundError or ImportError:
+        subprocess.call("pipgeo fetch --lib fiona", shell=True)
+    except Exception as e:
+        logger.exception(e)
+    try:
+        import geopandas as gpd
+    except ImportError:
+        subprocess.call(
+            f"{sys.executable}" + " -m pip install geopandas", shell=True
+        )
+        import geopandas as gpd
+    except Exception as e:
+        logger.exception(e)
+
+
+if str(platform.python_version()) > "3.3.0":
+    from .async_down import downloader
+os.chdir(os.path.dirname(os.path.realpath(__file__)))
+lpath = os.path.dirname(os.path.realpath(__file__))
+sys.path.append(lpath)
+
+
+def version_latest(package):
+    response = requests.get(f'https://pypi.org/pypi/{package}/json')
+    latest_version = response.json()['info']['version']
+    return latest_version
+
+
 def porder_version():
-    url = "https://pypi.org/project/porder/"
-    source = requests.get(url)
-    html_content = source.text
-    soup = BeautifulSoup(html_content, "html.parser")
-    company = soup.find("h1")
     vcheck = ob1.compareVersion(
-        company.string.strip().split(" ")[-1],
+        version_latest('porder'),
         pkg_resources.get_distribution("porder").version,
     )
     if vcheck == 1:
@@ -164,7 +149,7 @@ def porder_version():
         print(
             "Current version of porder is {} upgrade to lastest version: {}".format(
                 pkg_resources.get_distribution("porder").version,
-                company.string.strip().split(" ")[-1],
+                version_latest('porder'),
             )
         )
         print(
@@ -178,7 +163,7 @@ def porder_version():
         print(
             "Possibly running staging code {} compared to pypi release {}".format(
                 pkg_resources.get_distribution("porder").version,
-                company.string.strip().split(" ")[-1],
+                version_latest('porder'),
             )
         )
         print(
@@ -189,8 +174,6 @@ def porder_version():
 porder_version()
 
 
-
-
 # Go to the readMe
 def readme():
     try:
@@ -204,21 +187,60 @@ def readme():
 def read_from_parser(args):
     readme()
 
+# Initialize planet auth & save the token
+
+
+def init():
+    try:
+        url = "https://api.planet.com/auth/v1/experimental/public/users/authenticate"
+        payload = json.dumps({
+            "email": input("Email address:  "),
+            "password": getpass.getpass("Password:  ")
+        })
+        headers = {'Content-Type': 'application/json'}
+        response = requests.post(url, headers=headers, data=payload)
+        if response.status_code == 200:
+            with open(os.path.join(expanduser("~"), "planet.auth.json"), "w") as outfile:
+                json.dump(response.json(), outfile)
+        else:
+            print(f'Failed with status code {response.status_code}')
+    except Exception as error:
+        print(error)
+
+
+def init_from_parser(args):
+    init()
+
+# Get Planet API and Authenticate SESSION
+
+
+def authenticate_session():
+    try:
+        if not os.path.exists(os.path.join(expanduser("~"), "planet.auth.json")):
+            init()
+        else:
+            with open(os.path.join(expanduser("~"), "planet.auth.json")) as json_file:
+                token_data = json.load(json_file)
+                encoded = token_data["token"]
+                api_key = jwt.decode(encoded, options={"verify_signature": False})[
+                    'api_key']
+        PL_API_KEY = api_key
+    except:
+        print("Failed to get Planet Key")
+        sys.exit()
+    SESSION = requests.Session()
+    SESSION.auth = (PL_API_KEY, "")
+    return SESSION
+
 
 # Function to get user's quota
 def planet_quota():
     # Get API Key: Requires user to have initialized Planet CLI
-    try:
-        api_key = find_api_key()
-        os.environ["PLANET_API_KEY"] = find_api_key()
-    except Exception as e:
-        print("Failed to get Planet Key: Try planet init")
-        sys.exit()
+    SESSION = authenticate_session()
     """Print allocation and remaining quota in Sqkm."""
     try:
-        main = requests.get(
-            "https://api.planet.com/auth/v1/experimental/public/my/subscriptions",
-            auth=(api_key, ""),
+        main = SESSION.get(
+            "https://api.planet.com/auth/v1/experimental/public/my/subscriptions"
         )
         if main.status_code == 200:
             content = main.json()
@@ -227,7 +249,8 @@ def planet_quota():
                     print(" ")
                     print("Subscription ID: %s" % item_id["id"])
                     print("Plan ID: %s" % item_id["plan_id"])
-                    print("Allocation Name: %s" % item_id["organization"]["name"])
+                    print("Allocation Name: %s" %
+                          item_id["organization"]["name"])
                     print(
                         "Allocation active from: %s"
                         % item_id["active_from"].split("T")[0]
@@ -242,7 +265,8 @@ def planet_quota():
                     print("Total Quota used: %s" % item_id["quota_used"])
                     if (item_id["quota_sqkm"]) is not None:
                         leftquota = float(
-                            item_id["quota_sqkm"] - float(item_id["quota_used"])
+                            item_id["quota_sqkm"] -
+                            float(item_id["quota_used"])
                         )
                         print("Remaining Quota in SqKm: %s" % leftquota)
                     else:
@@ -263,7 +287,27 @@ def planet_quota_from_parser(args):
     planet_quota()
 
 
+def convert(folder, export):
+    for items in os.listdir(folder):
+        if items.endswith(".shp"):
+            inD = gpd.read_file(os.path.join(folder, items), encoding="utf-8")
+            # Reproject to EPSG 4326
+            try:
+                data_proj = inD.copy()
+                data_proj["geometry"] = data_proj["geometry"].to_crs(epsg=4326)
+                data_proj.to_file(
+                    os.path.join(export, str(
+                        items).replace(".shp", ".geojson")),
+                    driver="GeoJSON",
+                )
+                print(
+                    f"Export completed to {os.path.join(export, str(items).replace('.shp', '.geojson'))}")
+            except Exception as e:
+                print(e)
+
 # Convert folder with multiple shapefiles to geojsons
+
+
 def convert_metadata_from_parser(args):
     convert(folder=args.source, export=args.destination)
 
@@ -287,7 +331,34 @@ def gcs_cred_from_parser(args):
     gcs_cred(cred=args.cred)
 
 
+def vertexcount(inp):
+    gdf = gpd.read_file(inp)
+    nodes = []
+    for index, row in gdf.iterrows():
+        for pt in list(row['geometry'].exterior.coords):
+            nodes.append(pt)
+
+    return len(nodes)
+
+
+def geosimple(inp, output, num):
+    gdf = gpd.read_file(inp)
+    print(f"Vertex count {vertexcount(inp)}")
+    ft = gdf.to_json()
+    ft = json.loads(ft).get('features')[0]
+    try:
+        b = vw.simplify_feature(ft, number=num-1)
+        ft["geometry"]["coordinates"] = b["geometry"]["coordinates"]
+        with open(output, "w") as g:
+            json.dump(ft, g)
+        print(f"Write Completed to: {output}")
+        print(f"New vertex count {vertexcount(output)}")
+    except Exception as e:
+        print(e)
+
 # Simplify geojson by vertex count
+
+
 def simplify_from_parser(args):
     geosimple(inp=args.input, output=args.output, num=args.number)
 
@@ -303,13 +374,7 @@ def idlist_from_parser(args):
                 for item_types in mydict:
                     if args.item == item_types:
                         print(
-                            "Assets for item "
-                            + str(args.item)
-                            + " of Bundle type "
-                            + str(key)
-                            + ": "
-                            + str(", ".join(mydict[args.item]))
-                        )
+                            f"Assets for item {args.item} of Bundle type {key} : {', '.join(mydict[args.item])}")
         sys.exit()
     idl(
         infile=args.input,
@@ -326,27 +391,6 @@ def idlist_from_parser(args):
     )
 
 
-# Convert folder with multiple shapefiles to geojsons
-def idcheck_from_parser(args):
-    idc(idlist=args.idlist, item=args.item, asset=args.asset, geometry=args.geometry)
-
-
-# Check difference from local filelist
-def difflist_from_parser(args):
-    checker(
-        folder=args.folder,
-        typ=args.typ,
-        infile=args.input,
-        item=args.item,
-        asset=args.asset,
-        start=args.start,
-        end=args.end,
-        cmin=args.cmin,
-        cmax=args.cmax,
-        outfile=args.outfile,
-    )
-
-
 # Offcourse all good merge sometimes needs a split
 def idsplit_from_parser(args):
     idsplit(infile=args.idlist, linenum=args.lines, output=args.local)
@@ -354,17 +398,22 @@ def idsplit_from_parser(args):
 
 # Get package version
 def bundles(item):
-    url = "https://developers.planet.com/theme/js/scrub_all_bundles_bundle_spec.json"
-    date_response = requests.get(url).json()
+    page_url = "https://developers.planet.com/apis/orders/product-bundles-reference/"
+    req = requests.get(page_url)
+    soup = BeautifulSoup(req.text, "html.parser")
+    for link in soup.find_all('a', href=True):
+        if link.get('href').endswith('.json'):
+            bundle_url = link.get('href')
+    date_response = requests.get(bundle_url).json()
     ref_date = dateutil.parser.parse(date_response['version'])
     with open(os.path.join(lpath, "bundles.json")) as f:
-        r=json.load(f)
-        current= r['version']
+        r = json.load(f)
+        current = r['version']
         curr_date = dateutil.parser.parse(current)
     if curr_date < ref_date:
         print("Refreshing bundles to " + "\n" + str(date_response['version']))
         try:
-            url = "https://developers.planet.com/theme/js/scrub_all_bundles_bundle_spec.json"
+            url = bundle_url
             dest = os.path.join(lpath, "bundles.json")
             obj = SmartDL(url, dest)
             obj.start()
@@ -402,8 +451,8 @@ def order_from_parser(args):
         asset=args.bundle,
         sid=args.sid,
         op=args.op,
-        anchor = args.anchor,
-        format = args.format,
+        anchor=args.anchor,
+        format=args.format,
         boundary=args.boundary,
         projection=args.projection,
         gee=args.gee,
@@ -424,14 +473,12 @@ def reorder_from_parser(args):
 def cancel(id):
     headers = {"Content-Type": "application/json"}
     # Get API Key: Requires user to have initialized Planet CLI
-    try:
-        api_key = find_api_key()
-    except Exception as e:
-        print("Failed to get Planet Key: Try planet init")
-        sys.exit()
+    SESSION = authenticate_session()
+    SESSION.headers.update(headers)
     if id == "all":
         url = "https://api.planet.com/compute/ops/bulk/orders/v2/cancel"
-        resp = requests.post(url, data="{}", headers=headers, auth=(api_key, ""))
+        resp = requests.post(
+            url, data="{}", headers=headers, auth=(api_key, ""))
         if resp.status_code == 200:
             print(
                 "Number of orders failed to cancel: "
@@ -465,24 +512,47 @@ def cancel(id):
 def cancel_from_parser(args):
     cancel(id=args.id)
 
-
 # Get size of order in human size
+
+
+size_list = []
+suffixes = ["B", "KB", "MB", "GB", "TB", "PB"]
+
+
+def humansize(nbytes):
+    i = 0
+    while nbytes >= 1024 and i < len(suffixes) - 1:
+        nbytes /= 1024.0
+        i += 1
+    f = ("%.2f" % nbytes).rstrip("0").rstrip(".")
+    return "%s %s" % (f, suffixes[i])
+
+
+def ordersize(url):
+    SESSION = authenticate_session()
+    response = SESSION.get(url).json()
+    if response["state"] == "success" or response["state"] == "partial":
+        print("")
+        print("Order completed with status: " + str(response["state"]))
+        for files in response["_links"]["results"]:
+            if files["name"].endswith("manifest.json"):
+                time.sleep(0.2)
+                resp = SESSION.get(files["location"]).json()
+                for things in resp["files"]:
+                    size_list.append(things["size"])
+        print("Estimated Download Size for order: {}".format(
+            humansize(sum(size_list))))
+    else:
+        print(f'Order size can only be estimated ')
+
+
 def ordersize_from_parser(args):
     ordersize(url=args.url)
 
 
 # Get concurrent orders that are running
 def stats():
-    # Get API Key: Requires user to have initialized Planet CLI
-    try:
-        api_key = find_api_key()
-        os.environ["PLANET_API_KEY"] = find_api_key()
-    except Exception as e:
-        print("Failed to get Planet Key: Try planet init")
-        sys.exit()
-
-    SESSION = requests.Session()
-    SESSION.auth = (api_key, "")
+    SESSION = authenticate_session()
     print("Checking on all running orders...")
     result = SESSION.get("https://api.planet.com/compute/ops/stats/orders/v2")
     if int(result.status_code) == 200:
@@ -503,7 +573,8 @@ def stats():
                 + str(page["user"]["queued_orders"])
             )
             print(
-                "Total running orders for user: " + str(page["user"]["running_orders"])
+                "Total running orders for user: " +
+                str(page["user"]["running_orders"])
             )
         except Exception as e:
             print(e)
@@ -537,22 +608,8 @@ def asyncdownload_from_parser(args):
 def multiproc_from_parser(args):
     if str(platform.python_version()) > "3.3.0":
         downloader(url=args.url, final=args.local, ext=args.ext)
-    elif str(platform.python_version()) <= "3.3.0":
-        if args.ext == None:
-            subprocess.call(
-                "python multiproc_pydl.py " + args.url + " " + args.local + " ",
-                shell=True,
-            )
-        else:
-            subprocess.call(
-                "python multiproc_pydl.py "
-                + args.url
-                + " "
-                + args.local
-                + " "
-                + args.ext,
-                shell=True,
-            )
+    else:
+        print('Python version too old')
 
 
 print("")
@@ -569,20 +626,27 @@ def main(args=None):
     )
     parser_read.set_defaults(func=read_from_parser)
 
+    parser_init = subparsers.add_parser(
+        "init", help="Initialize tool & store authentication token")
+    parser_init.set_defaults(func=init_from_parser)
+
     parser_planet_quota = subparsers.add_parser(
         "quota", help="Prints your Planet Quota Details"
     )
     parser_planet_quota.set_defaults(func=planet_quota_from_parser)
 
     parser_convert = subparsers.add_parser(
-        "convert", help="Convert all shapefiles or kmls in folder to GeoJSON"
+        "convert", help="Convert all shapefiles in folder to GeoJSON"
     )
     parser_convert.add_argument("--source", help="Choose Source Folder")
-    parser_convert.add_argument("--destination", help="Choose Destination Folder")
+    parser_convert.add_argument(
+        "--destination", help="Choose Destination Folder")
     parser_convert.set_defaults(func=convert_metadata_from_parser)
 
-    parser_gcs_cred = subparsers.add_parser("base64", help="Base 64 encode a JSON file")
-    required_named = parser_gcs_cred.add_argument_group("Required named arguments.")
+    parser_gcs_cred = subparsers.add_parser(
+        "base64", help="Base 64 encode a JSON file")
+    required_named = parser_gcs_cred.add_argument_group(
+        "Required named arguments.")
     required_named.add_argument(
         "--cred", help="Path to GCS credential file", required=True
     )
@@ -593,7 +657,8 @@ def main(args=None):
         help="Simplifies geometry to number of vertices specified using Visvalingam-Wyatt line simplification algorithm",
     )
     parser_simplify.add_argument("--input", help="Input GeoJSON file")
-    parser_simplify.add_argument("--output", help="Output simplified GeoJSON file")
+    parser_simplify.add_argument(
+        "--output", help="Output simplified GeoJSON file")
     parser_simplify.add_argument(
         "--number", help="Total number of vertices in output GeoJSON"
     )
@@ -602,9 +667,10 @@ def main(args=None):
     parser_idlist = subparsers.add_parser(
         "idlist", help="Get idlist using geometry & filters"
     )
-    required_named = parser_idlist.add_argument_group("Required named arguments.")
+    required_named = parser_idlist.add_argument_group(
+        "Required named arguments.")
     required_named.add_argument(
-        "--input", help="Input geometry file for now geojson/json/kml", required=True
+        "--input", help="Input geometry file for now geojson/json", required=True
     )
     required_named.add_argument(
         "--start", help="Start Date &/or Time yyyy-mm-ddTHH:MM:SS", required=True
@@ -620,8 +686,10 @@ def main(args=None):
     required_named.add_argument(
         "--asset", help="Asset Type analytic, analytic_sr,visual etc", default=None
     )
-    required_named.add_argument("--outfile", help="Output csv file", required=True)
-    optional_named = parser_idlist.add_argument_group("Optional named arguments")
+    required_named.add_argument(
+        "--outfile", help="Output csv file", required=True)
+    optional_named = parser_idlist.add_argument_group(
+        "Optional named arguments")
     optional_named.add_argument(
         "--cmin", help="Minimum cloud cover 0-1 represents 0 to 100", default=None
     )
@@ -646,44 +714,6 @@ def main(args=None):
     )
     parser_idlist.set_defaults(func=idlist_from_parser)
 
-    parser_difflist = subparsers.add_parser(
-        "difflist",
-        help="Checks the difference between local files and available Planet assets",
-    )
-    required_named = parser_difflist.add_argument_group("Required named arguments.")
-    required_named.add_argument(
-        "--folder",
-        help="local folder where image or metadata files are stored",
-        required=True,
-    )
-    required_named.add_argument(
-        "--typ", help="File type image or metadata", required=True
-    )
-    required_named.add_argument(
-        "--input", help="Input boundary to search (geojson, json)", required=True
-    )
-    required_named.add_argument(
-        "--item",
-        help="Planet Item Type PSScene4Band|PSOrthoTile|REOrthoTile etc",
-        required=True,
-    )
-    required_named.add_argument(
-        "--asset", help="Asset Type analytic, analytic_sr,visual etc", required=True
-    )
-    required_named.add_argument("--start", help="Start date in format YYYY-MM-DD", required=True)
-    required_named.add_argument("--end", help="End date in format YYYY-MM-DD", required=True)
-    required_named.add_argument(
-        "--outfile", help="Full path to CSV file with difference ID list", required=True
-    )
-    optional_named = parser_difflist.add_argument_group("Optional named arguments")
-    optional_named.add_argument(
-        "--cmin", help="Minimum cloud cover 0-1 represents 0 to 100"
-    )
-    optional_named.add_argument(
-        "--cmax", help="Maximum cloud cover 0-1 represents 0 to 100"
-    )
-    parser_difflist.set_defaults(func=difflist_from_parser)
-
     parser_idsplit = subparsers.add_parser(
         "idsplit", help="Splits ID list incase you want to run them in small batches"
     )
@@ -696,18 +726,6 @@ def main(args=None):
     )
     parser_idsplit.set_defaults(func=idsplit_from_parser)
 
-    parser_idcheck = subparsers.add_parser(
-        "idcheck", help="Check idlist for estimating clipped area"
-    )
-    parser_idcheck.add_argument("--idlist", help="Idlist csv file")
-    parser_idcheck.add_argument("--item", help="Item type")
-    parser_idcheck.add_argument("--asset", help="Asset type")
-    optional_named = parser_idcheck.add_argument_group("Optional named arguments")
-    optional_named.add_argument(
-        "--geometry", help="Geometry file for clip if any", default=None
-    )
-    parser_idcheck.set_defaults(func=idcheck_from_parser)
-
     parser_bundles = subparsers.add_parser(
         "bundles", help="Check bundles of assets for given tiem type"
     )
@@ -718,7 +736,8 @@ def main(args=None):
         "order",
         help='Place an order & get order url currently supports "toar","clip","composite","reproject","compression"',
     )
-    required_named = parser_order.add_argument_group("Required named arguments.")
+    required_named = parser_order.add_argument_group(
+        "Required named arguments.")
     required_named.add_argument(
         "--name", help="Order Name to be Submitted", required=True
     )
@@ -735,11 +754,12 @@ def main(args=None):
         help="Bundle Type: analytic, analytic_sr,analytic_sr_udm2",
         required=True,
     )
-    optional_named = parser_order.add_argument_group("Optional named arguments")
+    optional_named = parser_order.add_argument_group(
+        "Optional named arguments")
     optional_named.add_argument("--sid", help="Subscription ID", default=None)
     optional_named.add_argument(
         "--boundary",
-        help="Boundary/geometry for clip operation geojson|json|kml",
+        help="Boundary/geometry for clip operation geojson|json",
         default=None,
     )
     optional_named.add_argument(
@@ -790,16 +810,21 @@ def main(args=None):
 
     parser_order.set_defaults(func=order_from_parser)
 
-    parser_reorder = subparsers.add_parser("reorder", help="Reorder an existing order")
-    required_named = parser_reorder.add_argument_group("Required named arguments.")
-    required_named.add_argument("--url", help="Order url to be ordered", required=True)
-    optional_named = parser_reorder.add_argument_group("Optional named arguments")
+    parser_reorder = subparsers.add_parser(
+        "reorder", help="Reorder an existing order")
+    required_named = parser_reorder.add_argument_group(
+        "Required named arguments.")
+    required_named.add_argument(
+        "--url", help="Order url to be ordered", required=True)
+    optional_named = parser_reorder.add_argument_group(
+        "Optional named arguments")
     optional_named.add_argument(
         "--notification", help='Use "email" to get an email notification', default=None
     )
     parser_reorder.set_defaults(func=reorder_from_parser)
 
-    parser_cancel = subparsers.add_parser("cancel", help="Cancel queued order(s)")
+    parser_cancel = subparsers.add_parser(
+        "cancel", help="Cancel queued order(s)")
     parser_cancel.add_argument(
         "--id", help='order id you want to cancel use "all" to cancel all'
     )
@@ -808,7 +833,8 @@ def main(args=None):
     parser_ordersize = subparsers.add_parser(
         "ordersize", help="Estimate total download size"
     )
-    parser_ordersize.add_argument("--url", help="order url you got for your order")
+    parser_ordersize.add_argument(
+        "--url", help="order url you got for your order")
     parser_ordersize.set_defaults(func=ordersize_from_parser)
 
     parser_ostate = subparsers.add_parser(
@@ -818,9 +844,11 @@ def main(args=None):
         "--state",
         help="choose state between queued| running | success | failed | partial",
     )
-    parser_ostate.add_argument("--start", help="start date in format YYYY-MM-DD")
+    parser_ostate.add_argument(
+        "--start", help="start date in format YYYY-MM-DD")
     parser_ostate.add_argument("--end", help="end date in format YYYY-MM-DD")
-    optional_named = parser_ostate.add_argument_group("Optional named arguments")
+    optional_named = parser_ostate.add_argument_group(
+        "Optional named arguments")
     optional_named.add_argument(
         "--limit", help="Limit the maximum table size", default=None
     )
@@ -834,11 +862,13 @@ def main(args=None):
     parser_download = subparsers.add_parser(
         "download", help="Downloads all files in your order"
     )
-    parser_download.add_argument("--url", help="order url you got for your order")
+    parser_download.add_argument(
+        "--url", help="order url you got for your order")
     parser_download.add_argument(
         "--local", help="Output folder where ordered files will be exported"
     )
-    optional_named = parser_download.add_argument_group("Optional named arguments")
+    optional_named = parser_download.add_argument_group(
+        "Optional named arguments")
     optional_named.add_argument(
         "--ext", help="File Extension to download", default=None
     )
@@ -847,11 +877,13 @@ def main(args=None):
     parser_asyncdownload = subparsers.add_parser(
         "multipart", help="Uses multiprocessing to download for all files in your order"
     )
-    parser_asyncdownload.add_argument("--url", help="order url you got for your order")
+    parser_asyncdownload.add_argument(
+        "--url", help="order url you got for your order")
     parser_asyncdownload.add_argument(
         "--local", help="Output folder where ordered files will be exported"
     )
-    optional_named = parser_asyncdownload.add_argument_group("Optional named arguments")
+    optional_named = parser_asyncdownload.add_argument_group(
+        "Optional named arguments")
     optional_named.add_argument(
         "--ext", help="File Extension to download", default=None
     )
@@ -861,11 +893,13 @@ def main(args=None):
         "multiproc",
         help="Multiprocess based downloader to download for all files in your order",
     )
-    parser_multiproc.add_argument("--url", help="order url you got for your order")
+    parser_multiproc.add_argument(
+        "--url", help="order url you got for your order")
     parser_multiproc.add_argument(
         "--local", help="Output folder where ordered files will be exported"
     )
-    optional_named = parser_multiproc.add_argument_group("Optional named arguments")
+    optional_named = parser_multiproc.add_argument_group(
+        "Optional named arguments")
     optional_named.add_argument(
         "--ext", help="File Extension to download", default=None
     )
@@ -879,5 +913,5 @@ def main(args=None):
     func(args)
 
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     main()
